"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class BaseModel {
    constructor(model) {
        this.model = model;
    }
    find(conditions = {}, projection = {}, options = {}) {
        return this.model.find(conditions, projection, options);
    }
    findAll() {
        return this.model.find();
    }
    findById(id) {
        return this.model.findById(id);
    }
    async findByIdAndRemove(id) {
        const doc = await this.model.findById(id);
        return await doc.remove();
    }
    async findByIdAndUpdate(id, update, options) {
        const doc = await this.model.findById(id);
        this._updateDocProperties(doc, update);
        return await doc.save();
    }
    findOne(conditions, projection = {}, options = {}) {
        return this.model.findOne(conditions, projection, options);
    }
    async insertMany(docs) {
        return await this.model.insertMany(docs);
    }
    async insertOne(doc) {
        return await this.model.create(doc);
    }
    async removeOne(conditions, projection = {}, options = {}) {
        return await this.model.deleteOne(conditions);
    }
    async updateMany(conditions, update, options) {
        const docs = await this.model.find(conditions);
        for (const doc of docs) {
            this._updateDocProperties(doc, update);
            await doc.save();
        }
        return docs;
    }
    async updateOne(conditions, update, options) {
        const doc = await this.model.findOne(conditions);
        this._updateDocProperties(doc, update);
        return await doc.save();
    }
    _updateDocProperties(doc, update, strict = false) {
        for (const prop in update) {
            if (!strict || doc.toObject().hasOwnProperty(prop)) {
                doc[prop] = update[prop];
            }
        }
    }
}
exports.BaseModel = BaseModel;
