"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("./common");
const mongoose_constants_1 = require("./mongoose.constants");
function createMongooseProviders(connectionName = mongoose_constants_1.DEFAULT_DB_CONNECTION, models = []) {
    return (models || []).map(model => ({
        provide: common_1.getModelToken(model.name),
        useFactory: (connection) => {
            if (model.hooks) {
                for (const hook of model.hooks) {
                    switch (hook.type) {
                        case 'post':
                            model.schema.post(hook.method, (doc) => hook.fn(doc, connection));
                            break;
                        case 'pre':
                            model.schema.pre(hook.method, function (next) {
                                hook.fn(this, next, connection);
                            });
                    }
                }
            }
            return connection.model(model.name, model.schema, model.collection);
        },
        inject: [
            connectionName === mongoose_constants_1.DEFAULT_DB_CONNECTION
                ? mongoose_constants_1.DEFAULT_DB_CONNECTION
                : common_1.getConnectionToken(connectionName)
        ]
    }));
}
exports.createMongooseProviders = createMongooseProviders;
